@@ -48,23 +48,25 @@ class main():
     list1=["U","D","Uw","Dw"]
     list2=["R","L","Lw","Rw"]
     list3=["F","B","Fw","Bw"]
-    n1=int(n/2)
+    try:
+      n1=int(n/2)
+    except TypeError:
+      raise TypeError("Invalid number")
     if n% 2==0:
-        times=int(n/2)
+      times=int(n/2)
+      for ru in ruf:
+
+        moves.append(f"{n1}{ru}w")
+        if ru=="R":
+          list2.append(f"{n1}{ru}w")
+        elif ru=="U":
+          list1.append(f"{n1}{ru}w")
+        elif ru=="F":
+          list3.append(f"{n1}{ru}w")
+
     else:
         times=int(n/2)+1
     for i in range(3,times):
-      if n % 2==0:
-          for ru in ruf:
-
-              moves.append(f"{n1}{ru}w")
-              if ru=="R":
-                  list2.append(f"{n1}{ru}w")
-              elif ru=="U":
-                  list1.append(f"{n1}{ru}w")
-              elif ru=="F":
-                  list3.append(f"{n1}{ru}w")
-
       for move in moveslist:
           moves.append(f"{i}{move}w")
           if move=="U" or move=="D":
@@ -133,7 +135,8 @@ class main():
       scramble.append(random.choice(possi))
       scramble.append(random.choice(possi2))
       return "".join(scramble)
-
+    else:
+      raise ValueError("Invalid scramble type")
 def get1():
   moves = ["x","y","z"]
   turns = [" ","2 ","' "]
@@ -243,7 +246,8 @@ def get3(scramtype="3x3"):
 
     scramble="R' U' F " + " ".join(a) + " R' U' F"
     return scramble
-
+  else:
+    raise ValueError("Invalid scramble type")
 
 
 def get4(scramtype="4x4"):
@@ -297,6 +301,8 @@ def get4(scramtype="4x4"):
     scramble.append(random.choice(possi))
     scramble.append(random.choice(possi2))
     return "".join(scramble)
+  else:
+    raise ValueError("Invalid scramble type")
 
 def get5(scramtype="5x5"):
 
@@ -304,37 +310,39 @@ def get5(scramtype="5x5"):
     scramble=main.big(5)
   elif scramtype=="bld":
     scramble=main.big(5,"bld")
+  else:
+    raise ValueError("Invalid scramble type")
   return scramble
 
 
 def get6():
   scramble=main.big(6)
-  return "".join(scramble)
+  return scramble
 
 def get7():
   scramble=main.big(7)
-  return "".join(scramble)
+  return scramble
 
 def get8():
   scramble=main.big(8)
-  return "".join(scramble)
+  return scramble
 
 def get9():
   scramble=main.big(9)
-  return "".join(scramble)
+  return scramble
 
 def get10():
   scramble=main.big(10)
-  return "".join(scramble)
+  return scramble
 
 def get11():
   scramble=main.big(11)
-  return "".join(scramble)
+  return scramble
 
 def get12():
   scramble=main.big(12)
-  return "".join(scramble)
+  return scramble
 
 def get_big_cube(n=12,scramtype="big"):
   scramble=main.big(n,scramtype)
-  return "".join(scramble)
+  return scramble
