@@ -1,4 +1,9 @@
 import random
+from . import sq1scrambler, trim
+
+@trim
+def get_squan():
+    return sq1scrambler.call("sql_scrambler.getRandomScramble")
 
 def get_clock():
   moves = ["0+ ","1+ ","2+ ","3+ ","4+ ","5+ ","6+ ","1- ","2- ","3- ","4- ","5- "]
